@@ -12,3 +12,5 @@
 # limitations under the License.
 
 from .client import *  # noqa
+from .v1 import ClientV1  # noqa
+from .common.http import ClientError, VersionNotSupported  # noqa
