@@ -20,7 +20,7 @@ import time
 import six
 
 from ironic_inspector_client.common import http
-from ironic_inspector_client.common.i18n import _, _LW
+from ironic_inspector_client.common.i18n import _
 
 
 DEFAULT_API_VERSION = (1, 0)
@@ -58,7 +58,7 @@ class ClientV1(http.BaseClient):
 
     This code creates a client with API version *1.0* and a given Keystone
     `session
-    <http://docs.openstack.org/developer/keystoneauth/using-sessions.html>`_.
+    <https://docs.openstack.org/keystoneauth/latest/using-sessions.html>`_.
     The service URL is fetched from the service catalog in this case. Optional
     arguments ``service_type``, ``interface`` and ``region_name`` can be
     provided to modify how the URL is looked up.
@@ -110,9 +110,9 @@ class ClientV1(http.BaseClient):
                 _("Setting IPMI user name requires a new password"))
 
         if new_ipmi_password:
-            LOG.warning(_LW('Setting IPMI credentials via ironic-inspector '
-                            'is deprecated, this feature will be removed '
-                            'in the Pike release'))
+            LOG.warning('Setting IPMI credentials via ironic-inspector '
+                        'is deprecated, this feature will be removed '
+                        'in the Pike release')
 
         params = {'new_ipmi_username': new_ipmi_username,
                   'new_ipmi_password': new_ipmi_password}
@@ -285,7 +285,7 @@ class ClientV1(http.BaseClient):
         :param node_ident: node UUID or name
         :param interface: interface name
         :param field_sel: list of all fields for which to get data
-        :returns interface data in OrderedDict
+        :returns: interface data in OrderedDict
         """
         # Use OrderedDict to maintain order of user-entered fields
         iface_data = OrderedDict()
@@ -323,7 +323,7 @@ class ClientV1(http.BaseClient):
         :param node_ident: node UUID or name
         :param field_sel: list of all fields for which to get data
         :param vlan: list of vlans used to filter the lists returned
-        :returns list of interface data, each interface in a list
+        :returns: list of interface data, each interface in a list
         """
 
         # Get inventory data for this node
